#
# spec file for package qucs-s
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?sle_version} >= 1506000
%define gcc_ver 13
%else
%define gcc_ver 12
%endif

Name:           qucs-s
Version:        24.4.1
Release:        1.1
Summary:        Qucs with SPICE
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Electronics
URL:            https://ra3xdh.github.io/
Source:         https://github.com/ra3xdh/qucs_s/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        qucs-s.rpmlintrc
BuildRequires:  bison
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  gperf
%if 0%{?suse_version} >= 1600
BuildRequires:  cmake(Qt6Charts)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  cmake(Qt6PrintSupport)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Xml)
%else
BuildRequires:  gcc%{gcc_ver}-c++
BuildRequires:  cmake(Qt5Charts)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Xml)
%endif
Requires:       ngspice

%description
Qucs-S is a spin-off of the Qucs cross-platform circuit simulator. "S" letter indicates SPICE. The purpose of the Qucs-S subproject is to use free SPICE circuit simulation kernels with the Qucs GUI. It merges the power of SPICE and the simplicity of the Qucs GUI. Qucs intentionally uses its own SPICE incompatible simulation kernel Qucsator. It has advanced RF and AC domain simulation features, but most of the existing industrial SPICE models are incompatible with it. Qucs-S is not a simulator by itself, but it requires to use a simulation backend with it. The schematic document format of Qucs and Qucs-S are fully compatible.

%prep
%setup -q -n %{name}-%{version}

%build
%if 0%{?suse_version} >= 1600
%cmake -DWITH_QT6=ON
%else
%cmake -DCMAKE_CXX_COMPILER=/usr/bin/g++-%{gcc_ver}
%endif
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}/%{name}/

%check

%files
%{_bindir}/*
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1.gz
%{_mandir}/man1/qucsator_rf.1.gz
%{_mandir}/man1/qucsconv_rf.1.gz
%{_datadir}/metainfo/io.github.ra3xdh.qucs_s.metainfo.xml

%changelog
* Tue Nov 19 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 24.4.1:
  What's Changed
  + Update Russian translation by @antohami in #1038
  + Fix hardcoded version in Cauer LC filter by @ra3xdh in #1039
  + Improve graph rendering performance by @wawuwo in #1042
  + refactor: replace non-empty QString constructors with
    QStringLiteral() by @Integral-Tech in #1043
  + Update Qt to v6.8.0 LTS by @dsm in #1048
  + Add MetaInfo by @NN708 in #1056
  + Fix #1001 by @ivandi69 in #1057
  + Fix build for contrib directory by @NN708 in #1058
  + Fix pulsed current source issues by @ra3xdh in #1059
  + Update NEWS, VERSION, and MetaInfo by @ra3xdh in #1061
* Sat Nov  2 2024 Mikhail Paulyshka <me@mixaill.net>
- Added QtCharts dependency
- Update to 24.4.0:
  What's Changed
  + S-parameter viewer by @andresmmera in #936
  + Update XyceDigital library and examples by @ra3xdh in #947
  + Release/24.3.2 by @ra3xdh in #955
  + Fix build issues by @ThomasZecha in #957
  + Fix memory leak while simulator switch by @zergud in #960
  + Fix Ngspice run in CLI mode by @ra3xdh in #963
  + Fix disable simulation for XYCE by @ra3xdh in #965
  + Fix simulation properties edition by @ra3xdh in #969
  + Fix of BJTsub and Diode device by @ra3xdh in #983
  + fix wrong selected bounding box for elliptic arc by @zergud in #989
  + Fixed crash when no simulators found on first start by @ra3xdh in #992
  + Spar viewer: Fixes and New Features by @andresmmera in #991
  + Fix unnecessary setPen before draw_resize_handle by @zergud in #990
  + Fix #997 by @ivandi69 in #1005
  + Fix diode symbol setting by @ra3xdh in #1006
  + Fix missing text in schematic after upgrading to Qt-6.8.0 by @ivandi69 in #995
  + refactor: use QString() as empty QString constructor by @Integral-Tech in #1003
  + Apply normalize_value to POT value by @ra3xdh in #1014
  + Add SPICE entry for VCresitor by @ra3xdh in #1016
  + S-parameter Viewer: More fixes by @andresmmera in #1009
  + Apply path conversion only for saved schematic or schematic in projects by @ra3xdh in #1018
  + Upload SPICE_TLine library by @ra3xdh in #1019
  + Allow variables for diode parameters by @ra3xdh in #1021
  + Schottly diode symbol fix and update library tree after creating new library by @ra3xdh in #1027
  + Save the position / size of ExternSimDialog on exit. by @iwbnwif in #1028
  + Update NEWS.md and VERSION before release by @ra3xdh in #1032
  + Fixed context menu for tab diagram and ASCO execution error by @ra3xdh in #1035
* Sat Oct 12 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 24.3.2:
  What's Changed
  + Fixed editing of File-type properties #948
  + Implemented @model[param] syntax recognition for Parameter
    sweep #948
- Added empty %%check section
* Sat Sep 14 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 24.3.1:
  What's Changed
  + Refactor node by @wawuwo in #845
  + Replace Q3PtrList in diagram dialog by @wawuwo in #854
  + Fix issue #864 - QucsAttenuator 24.3.0 - Accept "." and "," as
    decimal separators by @andresmmera in #865
  + fixed component highlighting. by @dsm in #877
  + Remove Schematic::textCorr by @wawuwo in #879
  + QucsAttenuator: Ensure Zout=Zin in QW and Lpad attenuators by
    @andresmmera in #880
  + Migrate Properties to QList and Some Refactoring by @dsm in #858
  + Fix segfault when component is placed over a wire by @wawuwo in #881
  + Get rid of MouseActions::drawn by @wawuwo in #844
  + Refactor Schematic::selectElements by @wawuwo in #878
  + Russian translation by @antohami in #885
  + Fix assertion fail when schematic is scrolled right by 'Right'
    key by @wawuwo in #886
  + Fix wrong Octave path by @ra3xdh in #888
  + Add SPICE entry for DCblock, DCfeed by @ra3xdh in #891
  + Point type graph redering fix by @ra3xdh in #897
  + Fix issue #905 - The matching network tool gives incorrect results
    when conditionally stable data is provided by @andresmmera in #907
  + Matching tool: Keep dialog open in case the synthesis goes wrong
    by @andresmmera in #909
  + make stable release for created tag. by @dsm in #911
  + Fix font size alteration in subcircuit component symbol by @wawuwo in #912
  + Fix Qucsconv GUI by @ra3xdh in #916
  + use different version for snapshot build. by @dsm in #917
  + Fixed crash on editing missing subcircuit by @ra3xdh in #918
  + some improvements for release creation in CI. by @dsm in #919
  + Substutute relative library path when inserting component in
    schematic by @ra3xdh in #923
  + Improve temperature sweep by @ra3xdh in #925
  + Update NEWS.md, VERSION, and library by @ra3xdh in #927
  + fixed adding hash to application title. by @dsm in #928
  + Fixes before release by @ra3xdh in #931
  + update app icon to new one. by @dsm in #932
  + add app icon using cmake and rc file. by @dsm in #93
- Update to 24.3.0:
  New features
  + SpiceLibComp redesign. This device is renamed to Spice Library
    Device and provides an easy way to add SPICE model to schematic
    and assign symbol to it. See #679
  + Added possibity to import SPICE model for Diode, BJT, MOSFET,
    and JFET unified devices (blue) #795
  + Implemeted symbol files (*.sym) editing mode. These files are
    needed to attach symbol to SPICE devices #700
  + Redesign of schematic rendering engine. Improve rendering quality
    on HiDPI displays #723 (by @wawuwo )
  + Improved Qucsconv GUI to reflect new converter features #826
  + Improved libraries portability, relative path support for
    libraries, show libraries from project directory #567
  + Added a global setting for Ngspice compatibility mode (LTspice,
    HSPICE, etc.) #851
  + Add global Ngspice compatibility mode (LTspice/HSPICE/S3) setting #851
  + Updated attenuator and filter synthesis tools (by @andresmmera )
  + QucsatorRF updated to version 1.0.1
  Deprecated features
  + The *.qucs binary archives are not supported anymore. Use system
    archivers to pack the projects instead #811
  + The SweepModel property of Parameter Sweep simulaiton has been
    deprecated. It is not needed anymore after Ngspice has added
    variable sweep feature. Use variable sweep instead #839
  + Toolbars and status bar made always visible #852
  + Icons theme settings removed from settings dialog. These settings
    have no effect since v2.1.0 when unified and auto-generated icons
    were introduced.
  General improvements
  + The TEMP and TEMPER variables are recognized by parameter sweep to
    apply temperature sweep #816
  + Fixed ASCO optimization with QucsatorRF #830
  + Enabled variables as parameters for unified nonlinear devices
    and pulsed source #838 and #808
  + Fixed issues with XYCE simulation #701
  + Improved attenuator synthesis tool #722
  + Improved filter synthesis tool #715 #673
  + Redesign File->Open examples menu. Show open dialog instead of
    file manager #672
  + Qucs-S now follows XDG standard for cached data location #145
  + Apply .OPTION INTERP when simulating transient with parameter
    sweep; prevent broken par. sweep data #766
  + Implemented relative paths support for library devices #567
  Component library
  + Added PWM controllers (TL494, UC384x, etc.) library #846
  + Added Germanium diodes library #846
  + Added Mixer IC library containing SA612 model #846
  + Added Diodes extended library containing different USSR diodes
    models
  + Added new Varactor library #759
  + Added new PIN diode library #764
  Localization
  + Russian translation update
- Using Qt6 library on Tumbleweed
* Wed Aug 21 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 24.2.1:
  General improvements
  + Fixed zero output on DC bias simulation (F8) #667
  + Fixed build failure of the Fedora RPM because of RPATH in
    qucsator_rf
* Sun Jul  7 2024 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to 24.2.0:
  New features
  * QucsatorRF is now a part of the package; No need to compile and
    install qucsator manually #370
  * Qucs-RFLayout tool could be launched from Tools menu #465; this
    tool must be installed separately: https://github.com/thomaslepoix/Qucs-RFlayout
  * Redesign of the Qucsconv GUI #647
  * Improved matching tool backported from Qucs-0.0.20 #401
  * Added RF devices group; backported different RF devices for
    Qucsator #607
  General imporvements and fixes
  * Fixed parameter sweep step issues #186 @ivandi69
  * Fixed SPICE devices bounding box #590 #637
  * Fixed netlist export from CLI #639
  * Fixed parameter sweep simulation with Xyce #624
  * Revert explicit WITH_QT6 compile flag because of cmake bug #592
  * Fixed tuner issues for German locale #416
  * Refactoring in schematic editor #626 #618 @wawuwo
  Localization
  * Russian translation update
- Update to 24.1.0:
  Important notes
  * Versioning switched to CalVer. The first digit means year, the
    second digit means the release number, the third digit means
    patch number #328
  * Qucs-S is now on Telegram. Join https://t.me/qucs_s to ask
    questions and get news
  New features
  * Added 3-pin RCD devices #349 to improve support of
    microelectronics PDKs
  * Improvements of Ngspice support; allowed multiple simulation of
    the same type #463 by @ivandi69
  * Automatic extraction of THD from FOURIER simulation #525 @ivandi69
  * Nutmeg equations improvements; implemented simulation selection
    from drop-down list #463 #519
  * Improvements of Nutmeg script simulation type; implemented custom
    prefixes for plots #476 #435 @ivandi69
  * Export DC OP simulation data to dataset #463 #140 @ivandi69
  * Implemented zoom by selection on the rectangular plots #305
  * Implemeted potentiometer device #122
  * Switched digital simulation from FreeHDL to GHDL #395 @iwbnwif
  * Status bar improvements #493
  RF simulation features
  * Added RCLG device support for SPICE #564
  * Added YLIN device support for XYCE #451
  * Fixed touchstone simulation issues for Ngspice #392
  * Added BiasT device support for SPICE #374
  * Added option to disable transient model for RF port #410
  Libraries
  * Fixed different issues related to creating libraries #432
  * Added audio IC library
  * Added loudspeaker library #421
  * Added comparators library #436
  * Modified voltage regulators library #433
  * Added voltage references library #439
  * Added thermistor library #538
  * Fixed ideal library #258 #428
  * Fixed transformers library #362
  * Added new devices in SpiceOpamp library #501
  General improvements
  * Fixed different tuner issues
  * Schematic zooming improvements #502
  * Different improvements on schematic look and control
  * Added schematic pan mode with the middle mouse button #488
  * Many HiDPI support improvements including grid rendering
  * Fixed schematic glitches using Wayland #227
  * Added text document zoom and font setting #534
  Documentation
  * Added new examples
  * Added Ngspice templates #441
  * The readthdocs documentantion is a candidate for deprecation #554
  Localization
  * Added Chinese translation #453 by @hvwyl
- Update to 2.1.0:
  New features
  * Added tuner simulation mode #123 (used implementation by
    @tipofthesowrd)
  * Added support for touchstone s2p file devices for Ngspice #233
    (implementation by @transmitterdan)
  * Redesign of the simulation window #309
  * Diagrams are placed on schematic and *.dpl files are
    disabled by default #309
  * Backport of the active Legendre filter synthesis from
    Qucs-0.0.20rc2 #318
  * Added SPICE entry for MUT and MUT2 devices
  * Backported circular waveguide and tapered line symbols
    from Qucs-0.0.20rc2
  * Added zoom to selection mode #327
  * Toolbar icons replaced by SVG; improved look for HiDPI
    [#323] #304
  * Implemented automatic generation of high resolution device
    icons #334 #304
  General improvements
  * Added Tstart option for Spectrum simulaiton #336
  * Added low voltage for VRect source #310
  * Russian translation update #292 #324
  * Added SPICE group for project tree
  Bugfixes
  * Fixed simulation of the files with double extension #311
  * Fixed simulation of the files containing unicode symbols #312
  * Fixed display of the Xanalogue.lib library #308
  * Fixed show checker errors for Xyce
  * Fixed load symbol for Verilog-A device #321
  * Fixed component rotation with right mouse button
  Library
  * Added thyristor library #212
  * Added optocoupler library #213
  * Added photovoltaic relays library #222
  Documentation
  * Added subcircuit symbol templates to share/qucs_s/examples/symbols
    (by @tomhajjar)
  * Added sections on tuner mode and RF simulation to the Qucs-S
    tutorial
- Update to 2.0.0:
  Important notes
  * The simulator switching system was redesigned since this
    release. It allows now to switch simulation kernel without
    restart of the application. But it is required to reconfigure
    simulator paths even if it was configured for the previous
    installation. A Simulator settings dialog window will appear
    on the first application start after the update. Please
    check the simulator settings and correct if necessary to
    continue work.
  New features
  * Implemented quick switch of the simulator without
    application restart #274 (thanks @zergud)
  Component library
  * Fixed issues in Transformers library #228 and #231
  General improvements
  * Finished Qt6 porting #190
  * Show warning if the directory protected by Windows UAC #282
  * Fixed PDF print on Windows #285
  * Added option to export grayscale image #288
  * Fixed setting initial conditions in wire labels #291
  * Fixed missing ground warning
- Update to 1.1.0:
  New features
  * Qucs-S supports digital simulation mode using IcarusVerilog
    or FreeHDL backends #97
  * Added analog model for digital source #265
  * Qucs-S runs DC bias simulation mode if schematic contains DC
    simulation only #271
  * Selection rectangle update #276
  Deprecated features
  * XSPICE CodeModel synthesizer has been deprecated since v1.1.0.
    The precompiled CM libraries are still supported using
    spiceinit virtual device. See #204
  Known issues of digital simulation
  * Digital buses are not supported;
  * Digital simulation represents its state as of Qucs-0.0.20-RC1;
    No new features added
* Sun May 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Added XSPICE flip-flop digital devices
  * Added INDQ and CAPQ devices representing inductor and
    capacitor with Q-factor
  * Added .LIB directive support
  * Added SPICE entries for I and V file sources
  * Added symbols for 4 and 5 terminal BJT device
  * Added behavioral XSPICE 555 timer model
  * Added option to save SPICE netlist without simulation
  * Improved Qt6 compatibility
  * Improved MacOS compatibility
  * CMake build system update to bring features of the modern
    CMake
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.1:
  * Added support for Verilog-A defined devices using
    Ngspice+OpenVAF #197. Old Qucsator+ADMS
    workflow is marked as deprecated. Ngspice >=39 is required
    to support OpenVAF.
  * Implemented variable parameter sweep analysis #189
  * Added possibility to build Qucs-S with Qt6 #190 The
  - DWITH=QT6=ON option for cmake is required.
  * The source code of the Qucs-S is Qt6 compatible now.
  * Simulator prefixes like "ngspice/" are not show anymore on
    plot traces if the plot contains data
    from only one simulator #178
  * Added TL071/TL072 opamp models
  * Added 555_timer.lib library containing the 555 timer model
  * Added extended BJT exteneded and Schottky diodes libraries
  * Change default RCL device values and simulation settings to
    prevent convergence error when putting
    together device with default values #195
  * Fixed auto-scaling issue on Windows 64-bit platform #133
* Sat Nov 26 2022 Dmitry Roshchin <dmitry_r@opensuse.org>
- Initial package, version 1.0.0
